APEv2
=====

.. automodule:: mutagen.apev2

.. autoexception:: mutagen.apev2.error

.. autoexception:: mutagen.apev2.APENoHeaderError

.. autoexception:: mutagen.apev2.APEUnsupportedVersionError

.. autoexception:: mutagen.apev2.APEBadItemError

.. autoclass:: mutagen.apev2.APEv2File
    :show-inheritance:
    :members:

.. autoclass:: mutagen.apev2.APEv2
    :members:

    :bases: `mutagen.Metadata`
